@@ -45,6 +45,7 @@ static const char *default_srv_config = "{"
 static const char *default_css =
     "body { max-width: 48em; margin: auto; line-height: 1.5; padding: 0.8em; word-wrap: break-word; }\n"
     "pre { overflow-x: scroll; }\n"
+    "blockquote { font-style: italic; }\n"
     ".snac-embedded-video, img { max-width: 100% }\n"
     ".snac-origin { font-size: 85% }\n"
     ".snac-score { float: right; font-size: 85% }\n"
@@ -59,6 +60,7 @@ static const char *default_css =
     ".snac-top-controls { padding-bottom: 1.5em }\n"
     ".snac-post { border-top: 1px solid #a0a0a0; padding-top: 0.5em; padding-bottom: 0.5em; }\n"
     ".snac-children { padding-left: 1em; border-left: 1px solid #a0a0a0; }\n"
+    ".snac-thread-cont { border-top: 1px dashed #a0a0a0; }\n"
     ".snac-textarea { font-family: inherit; width: 100% }\n"
     ".snac-history { border: 1px solid #606060; border-radius: 3px; margin: 2.5em 0; padding: 0 2em }\n"
     ".snac-btn-mute { float: right; margin-left: 0.5em }\n"
@@ -100,8 +102,9 @@ static const char *greeting_html =
     "<html><head>\n"
     "<meta name=\"viewport\" content=\"width=device-width, initial-scale=1\"/>\n"
     "<link rel=\"icon\" type=\"image/x-icon\" href=\"https://%host%/favicon.ico\"/>\n"
+    "<style>*{color-scheme:light dark}body{margin:auto;max-width:50em}</style>\n"
     "<title>Welcome to %host%</title>\n</head>\n"
-    "<body style=\"margin: auto; max-width: 50em\">\n"
+    "<body>\n"
     "%blurb%"
     "<p>The following users are part of this community:</p>\n"
     "\n"
@@ -226,6 +229,9 @@ int snac_init(const char *basedir)
     xs *ibdir = xs_fmt("%s/inbox", srv_basedir);
     mkdirx(ibdir);
 
+    xs *langdir = xs_fmt("%s/lang", srv_basedir);
+    mkdirx(langdir);
+
     xs *gfn = xs_fmt("%s/greeting.html", srv_basedir);
     if ((f = fopen(gfn, "w")) == NULL) {
         printf("ERROR: cannot create '%s'\n", gfn);
@@ -250,7 +256,10 @@ int snac_init(const char *basedir)
     xs_json_dump(srv_config, 4, f);
     fclose(f);
 
-    printf("Done.\n");
+    printf("Done.\n\n");
+
+    printf("Wanted web UI language files (.po) must be copied manually to %s\n", langdir);
+
     return 0;
 }
 
@@ -486,6 +495,26 @@ void verify_links(snac *user)
 
     int c = 0;
     while (metadata && xs_dict_next(metadata, &k, &v, &c)) {
+        xs *wfinger = NULL;
+        const char *ov = NULL;
+
+        /* is it an account handle? */
+        if (*v == '@' && strchr(v + 1, '@')) {
+            /* resolve it via webfinger */
+            if (valid_status(webfinger_request(v, &wfinger, NULL)) && xs_is_string(wfinger)) {
+                ov = v;
+                v = wfinger;
+
+                /* store the alias */
+                if (user->links == NULL)
+                    user->links = xs_dict_new();
+
+                user->links = xs_dict_set(user->links, ov, v);
+
+                changed++;
+            }
+        }
+
         /* not an https link? skip */
         if (!xs_startswith(v, "https:/" "/"))
             continue;
@@ -658,7 +687,7 @@ void export_csv(snac *user)
             const char *lid = xs_list_get(li, 0);
             const char *ltitle = xs_list_get(li, 1);
 
-            xs *actors = list_content(user, lid, NULL, 0);
+            xs *actors = list_members(user, lid, NULL, 0);
             const char *md5;
 
             xs_list_foreach(actors, md5) {
@@ -703,6 +732,61 @@ void export_csv(snac *user)
 }
 
 
+void export_posts(snac *user)
+/* exports all posts to an OrderedCollection */
+{
+    xs *ifn = xs_fmt("%s/public.idx", user->basedir);
+    xs *index = index_list(ifn, XS_ALL);
+    xs *ofn = xs_fmt("%s/export/outbox.json", user->basedir);
+    FILE *f;
+
+    if ((f = fopen(ofn, "w")) == NULL) {
+        snac_log(user, xs_fmt("Cannot create file %s", ofn));
+        return;
+    }
+
+    int cnt = 0;
+
+    /* raw output */
+    fprintf(f, "{\"@context\": \"https:/" "/www.w3.org/ns/activitystreams\",");
+    fprintf(f, "\"id\": \"outbox.json\",");
+    fprintf(f, "\"type\": \"OrderedCollection\",");
+    fprintf(f, "\"orderedItems\": [");
+
+    const char *md5;
+
+    snac_log(user, xs_fmt("Creating %s...", ofn));
+
+    xs_list_foreach(index, md5) {
+        xs *obj = NULL;
+
+        if (!valid_status(object_get_by_md5(md5, &obj)))
+            continue;
+
+        const char *type = xs_dict_get(obj, "type");
+
+        if (!xs_is_string(type) || strcmp(type, "Note"))
+            continue;
+
+        const char *atto = get_atto(obj);
+
+        if (!xs_is_string(atto) || strcmp(atto, user->actor))
+            continue;
+
+        if (cnt)
+            fprintf(f, ",");
+
+        xs *c_msg = msg_create(user, obj);
+        xs_json_dump(c_msg, 0, f);
+        cnt++;
+    }
+
+    fprintf(f, "], \"totalItems\": %d}", cnt);
+
+    fclose(f);
+}
+
+
 void import_blocked_accounts_csv(snac *user, const char *ifn)
 /* imports a Mastodon CSV file of blocked accounts */
 {
@@ -829,7 +913,7 @@ void import_list_csv(snac *user, const char *ifn)
                     if (valid_status(webfinger_request(acct, &url, &uid))) {
                         xs *actor_md5 = xs_md5_hex(url, strlen(url));
 
-                        list_content(user, list_id, actor_md5, 1);
+                        list_members(user, list_id, actor_md5, 1);
                         snac_log(user, xs_fmt("Added %s to list %s", url, lname));
 
                         if (!following_check(user, url)) {
@@ -881,7 +965,7 @@ void import_csv(snac *user)
             if (*l) {
                 xs *post = NULL;
 
-                if (!object_get(l, &post)) {
+                if (!valid_status(object_get(l, &post))) {
                     if (!valid_status(activitypub_request(user, l, &post))) {
                         snac_log(user, xs_fmt("Error getting object %s for bookmarking", l));
                         continue;
@@ -911,3 +995,60 @@ void import_csv(snac *user)
     else
         snac_log(user, xs_fmt("Cannot open file %s", fn));
 }
+
+static const struct {
+    const char *proto;
+    unsigned short default_port;
+} FALLBACK_PORTS[] = {
+    /* caution: https > http, smpts > smtp */
+    {"https", 443},
+    {"http",  80},
+    {"smtps", 465},
+    {"smtp", 25}
+};
+
+int parse_port(const char *url, const char **errstr)
+{
+    const char *col, *rcol;
+    int tmp, ret = -1;
+
+    if (errstr)
+        *errstr = NULL;
+
+    if (!(col = strchr(url, ':'))) {
+        if (errstr)
+            *errstr = "bad url";
+
+        return -1;
+    }
+
+    for (size_t i = 0; i < sizeof(FALLBACK_PORTS) / sizeof(*FALLBACK_PORTS); ++i) {
+        if (memcmp(url, FALLBACK_PORTS[i].proto, strlen(FALLBACK_PORTS[i].proto)) == 0) {
+            ret = FALLBACK_PORTS[i].default_port;
+            break;
+        }
+    }
+
+    if (!(rcol = strchr(col + 1, ':')))
+        rcol = col;
+
+    if (rcol) {
+        tmp = atoi(rcol + 1);
+        if (tmp == 0) {
+            if (ret != -1)
+                return ret;
+
+            if (errstr)
+                *errstr = strerror(errno);
+
+            return -1;
+        }
+
+        return tmp;
+    }
+
+    if (errstr)
+        *errstr = "unknown protocol";
+
+    return -1;
+}
